#!/bin/sh

# Packager 		: Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# Packaging date 	: 18/02/2010
#
# package 		: fltk2
# homepage 		: http://www.fltk.org
# source location	: ftp://ftp.funet.fi/pub/mirrors/ftp.easysw.com/pub/fltk/snapshots/fltk-2.0.x-r6970.tar.bz2
set -e -u -x
#> log  
(

softname='fltk2'
softversion='2.0.x_r6970'
arch='i486'
zenver='64.1'
cpu='i686'

buildir=$(pwd)
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$zenver"
srcpkg="$buildir/fltk-2.0.x-r6970.tar.bz2"
dest="$buildir/$package"
srcurl=ftp://ftp.funet.fi/pub/mirrors/ftp.easysw.com/pub/fltk/snapshots/fltk-2.0.x-r6970.tar.bz2
sourcetemplate=http://zenwalk.pinguix.com/user-accounts/stillborn/fltk2

rm -rf $src
rm -f $dest.{txz,md5,dep,src}
rm -rf $dest

#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar -xjf $srcpkg
mv fltk-2.0.x-r6970 $softname-$softversion

mkdir -p $dest/{install,usr/{doc/$softname-$softversion,src/$softname-$softversion}}
cd $src

CFLAGS="-O2 -march=$arch -mtune=$cpu" \
CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \
./configure \
  --prefix=/usr \
  --libdir=/usr/lib \
  --mandir=/usr/man \
  --enable-shared || exit
make -j2 || exit
make install DESTDIR=$dest

#> prepare slack-desc
cat << "EOF" > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
fltk2: FLTK (Fast Light Tool Kit), version 2
fltk2:
fltk2: The Fast Light Tool Kit ("FLTK", pronounced "fulltick") is a LGPL'd
fltk2: C++ graphical user interface toolkit for X (UNIX(r)), OpenGL(r),
fltk2: and Microsoft(r) Windows(r). It was originally developed by Mr. Bill
fltk2: Spitzak and is currently maintained by a small group of developers
fltk2: across the world with a central repository in the US.
fltk2:
fltk2: Homepage: http://www.fltk.org/
fltk2:
fltk2:
EOF

#> no manpages are installed
rm -rfv $dest/usr/man

#> add docs, infos, ...
(  cd $src
   cp -av \
   CHANGES CREDITS README README.unix README_fltk1_to_fltk2.txt TODO COPYING \
   $dest/usr/doc/$softname-$softversion
)

#> store buildscript 
(  cd $buildir
   cp -v $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion/
)

#> Strip executables
(  cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#> fix permissions
(
   chown -R root.root $dest
   cd $dest
   find . -perm 664 -exec chmod 644 {} \;
   find . -perm 600 -exec chmod 644 {} \;
   find . -perm 444 -exec chmod 644 {} \;
   find . -perm 400 -exec chmod 644 {} \;
   find . -perm 440 -exec chmod 644 {} \;
   find . -perm 777 -exec chmod 755 {} \;
   find . -perm 775 -exec chmod 755 {} \;
   find . -perm 511 -exec chmod 755 {} \;
   find . -perm 711 -exec chmod 755 {} \;
   find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(  cd $dest;find . -printf "%Y %M %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(  cd $dest
   /sbin/makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
depfinder $package.txz > $package.dep
echo $sourcetemplate/build-$softname.sh > $package.src
echo $srcurl >> $package.src
) 2>&1 | tee build.fltk2.log.txt
